@@ -4,7 +4,7 @@ var path = require('path'),
 	execFile = require('child_process').execFile;
 
 module.exports = function (grunt) {
-	grunt.registerTask('data-zic', '2. Compile data sources with zic(8).', function (version) {
+	grunt.registerTask('data-zic', '3. Compile data sources with zic(8).', function (version) {
 		version = version || 'latest';
 
 		var done  = this.async(),
@@ -13,6 +13,24 @@ module.exports = function (grunt) {
 
 		grunt.file.mkdir(dest);
 
+		// Allow using custom zic binaries
+		var zicBinary = 'zic',
+			zicPathOption = grunt.option('zic-path');
+		if (zicPathOption && grunt.file.exists(zicPathOption)) {
+			zicBinary = zicPathOption;
+		}
+
+		// Do a test of `zic` to make sure it can provide the data we want.
+		// The presence of the `-b` argument (introduced in tzcode 2019b) is a good test, as its
+		// purpose is to help work around year-2038 bugs.
+		execFile(zicBinary, ['--help'], function (err, stdout) {
+			if (!stdout.includes('[ -b ')) {
+				grunt.log.warn('WARNING: The version of `zic` on this machine is old and might produce incorrect values');
+			}
+
+			next();
+		});
+
 		function next () {
 			if (!files.length) {
 				grunt.log.ok('Compiled zic for ' + version);
@@ -25,7 +43,7 @@ module.exports = function (grunt) {
 			if (!grunt.file.exists(src)) {
 				throw new Error("Can't process " + src + " with zic. File doesn't exist");
 			}
-			execFile('zic', ['-d', dest, src], function (err) {
+			execFile(zicBinary, ['-d', dest, src], function (err) {
 				if (err) { throw err; }
 
 				grunt.verbose.ok('Compiled zic ' + version + ':' + file);
@@ -33,7 +51,5 @@ module.exports = function (grunt) {
 				next();
 			});
 		}
-
-		next();
 	});
 };
